@@ -43,8 +43,8 @@
 #' ) %>%
 #'   read_sf() %>%
 #'   get_resources(
-#'     get_gfw_treecover(version = "GFC-2023-v1.11"),
-#'     get_gfw_lossyear(version = "GFC-2023-v1.11"),
+#'     get_gfw_treecover(version = "GFC-2024-v1.12"),
+#'     get_gfw_lossyear(version = "GFC-2024-v1.12"),
 #'     get_gfw_emissions()
 #'   ) %>%
 #'   calc_indicators(
@@ -54,7 +54,7 @@
 #'
 #' aoi
 #' }
-calc_treecover_area_and_emissions <- function(years = 2000:2023,
+calc_treecover_area_and_emissions <- function(years = 2000:2024,
                                               min_size = 10,
                                               min_cover = 35) {
   check_namespace("exactextractr")
@@ -102,7 +102,7 @@ calc_treecover_area_and_emissions <- function(years = 2000:2023,
         data <- .prep_gfw_data(data, min_size)
         losses <- .sum_gfw(data, "coverage_area", max_year)
         names(losses)[2] <- "loss"
-        emissions <- .sum_gfw(data, "emissions")
+        emissions <- .sum_gfw(data, "emissions", max_year)
 
         org_coverage <- sum(data[["coverage_area"]])
 
