@@ -115,15 +115,14 @@ get_resources <- function(x, ...) {
   invisible(resource)
 }
 
-
 .fetch_resource <- function(resource,
                             name = NULL,
                             type = NULL,
                             outdir = mapme_options()[["outdir"]],
                             verbose = mapme_options()[["verbose"]],
                             retries = mapme_options()[["retries"]]) {
-  stopifnot(inherits(resource, "sf"))
-  stopifnot(type %in% c("raster", "vector"))
+
+  stopifnot(inherits(resource, "sf"), type %in% c("raster", "vector"))
 
   if (is.null(outdir)) {
     resource[["location"]] <- resource[["source"]]
@@ -132,23 +131,23 @@ get_resources <- function(x, ...) {
       has_progressr <- check_namespace("progressr", error = FALSE)
       if (has_progressr) {
         n <- nrow(resource)
-        s <- 1
-        if (n > 100) {
+        s <- 1L
+        if (n > 100L) {
           s <- round(n * 0.01)
-          n <- 100
+          n <- 100L
         }
         p <- progressr::progressor(n)
       }
     }
 
     resource[["destination"]] <- file.path(outdir, resource[["filename"]])
-    resource <- lapply(1:nrow(resource), function(i) resource[i, ])
+    resource <- lapply(seq_len(nrow(resource)), function(i) resource[i, ])
 
     furrr::future_iwalk(resource, function(x, i) {
-      attempts <- 0
+      attempts <- 0L
 
       while (attempts < retries) {
-        attempts <- attempts + 1
+        attempts <- attempts + 1L
 
         is_available <- .get_spds(
           source = x[["source"]],
@@ -162,17 +161,34 @@ get_resources <- function(x, ...) {
         }
       }
 
-      if (verbose && has_progressr) {
-        if (i %% s == 0) {
-          p(message = sprintf("Fetching resource '%s'.", name))
-        }
+      if (verbose && has_progressr && (i %% s == 0L)) {
+        p(message = sprintf("Fetching resource '%s'.", name))
       }
     }, .options = furrr::furrr_options(seed = TRUE, chunk_size = 1L))
 
-    resource <- st_as_sf(do.call(rbind, resource))
+    resource <- sf::st_as_sf(do.call(rbind, resource))
     resource[["location"]] <- resource[["destination"]]
     is_available <- sapply(resource[["location"]], spds_exists, what = type)
-    resource[is_available, ]
+    if (isFALSE(all(is_available))) {
+      not_available_resource <- resource[!is_available, ]
+      msg <- sprintf("%d out of %d resources are not available for %s",
+                     nrow(not_available_resource), nrow(resource), name)
+      log_dir <- mapme_options()[["log_dir"]]
+      if (!is.null(log_dir)) {
+        dsn <- file.path(log_dir, paste0(Sys.Date(), "_", name,
+                                         "_mapme-error-resources.gpkg"))
+        # drop list columns to write GPKG
+        not_available_resource <- not_available_resource[,
+                                  setdiff(names(not_available_resource), c("oo", "co"))]
+        # sf::st_write(subset(not_available_resource, select = -c(oo, co)),
+        #              dsn, append = TRUE, quiet = TRUE)
+        sf::st_write(not_available_resource, dsn, append = TRUE, quiet = TRUE)
+        msg <- paste(msg, sprintf("The list can be found in %s", dsn), sep = "\n")
+      }
+      warning(msg, call. = FALSE)
+      resource <- resource[is_available, ]
+    }
   }
-  resource
+  return(resource)
 }
+
