@@ -35,12 +35,7 @@
 spds_exists <- function(path, oo = character(0), what = c("vector", "raster")) {
   what <- match.arg(what)
   # path <- normalizePath(path, mustWork = FALSE)
-  # On Windows this would add drive letter ('C:\\', etc.) at the beginning of the path,
-  # which is wrong for remote paths like '/vsicurl/https://...'
-  norm_path <- try(normalizePath(path, mustWork = TRUE), silent = TRUE)
-  if (!inherits(norm_path, "try-error")) {
-    path <- norm_path
-  }
+  path <- .normalize_source_path(path)
   util <- switch(what,
     vector = "ogrinfo",
     raster = "gdalinfo"
@@ -52,7 +47,8 @@ spds_exists <- function(path, oo = character(0), what = c("vector", "raster")) {
     ),
     raster = c("-json", "-nomd", "-norat", "-noct", oo)
   )
-  if (what == "vector" && sf::sf_extSoftVersion()[["GDAL"]] < "3.7.0") {
+  if (what == "vector" &&
+      (utils::compareVersion(sf::sf_extSoftVersion()[["GDAL"]], "3.7.0") < 0)) {
     util <- "gdalinfo"
     opts <- oo
   }
@@ -145,7 +141,8 @@ make_footprints <- function(srcs = NULL,
 
   if (inherits(srcs, "character")) {
     what <- match.arg(what)
-    srcs <- normalizePath(srcs, mustWork = FALSE)
+    # srcs <- normalizePath(srcs, mustWork = FALSE)
+    srcs <- .normalize_source_path(srcs)
     srcs <- switch(what,
       vector = purrr::map2(srcs, oo, function(src, opt) .vector_footprint(src, opt)),
       raster = purrr::map2(srcs, oo, function(src, opt) .raster_footprint(src, opt)),
@@ -195,8 +192,11 @@ prep_resources <- function(x, avail_resources = NULL, resources = NULL, mode = c
     stop("Some requested resources are not available.")
   }
 
-  out <- purrr::map(resources, function(resource) {
-    resource <- avail_resources[[resource]]
+  out <- purrr::map(resources, function(resource_name) {
+    resource <- avail_resources[[resource_name]]
+    if (nrow(resource) == 0L) {
+      stop(sprintf("Resource %s is empty", resource_name), call. = FALSE)
+    }
     resource_type <- unique(resource[["type"]])
     reader <- switch(resource_type,
       raster = .read_raster,
@@ -391,15 +391,16 @@ prep_resources <- function(x, avail_resources = NULL, resources = NULL, mode = c
   .geom_last(data)
 }
 
-
 .get_spds <- function(source = NULL,
                       destination = NULL,
                       opts = NULL,
                       what = c("vector", "raster")) {
   what <- match.arg(what)
   stopifnot(is.character(source) && length(source) == 1)
-  source <- normalizePath(source, mustWork = FALSE)
+  # source <- normalizePath(source, mustWork = FALSE)
+  source <- .normalize_source_path(source)
   stopifnot(is.character(destination) && length(destination) == 1)
+  # the destination will in general *NOT* exist, so we must use mustWork = FALSE
   destination <- normalizePath(destination, mustWork = FALSE)
   stopifnot(is.null(opts) || is.character(opts))
   if (is.null(opts)) opts <- character(0)
@@ -457,3 +458,15 @@ prep_resources <- function(x, avail_resources = NULL, resources = NULL, mode = c
 
   geom
 }
+
+.normalize_source_path <- function(path) {
+  # On Windows this would add drive letter ('C:\\', etc.) at the beginning of the path,
+  # which is wrong for remote paths like '/vsicurl/https://...'.
+  # Since the source file *MUST* exist, we can use mustWork = TRUE.
+  # In general, it is *NOT* recommended to use mustWork = FALSE.
+  norm_path <- try(normalizePath(path, mustWork = TRUE), silent = TRUE)
+  if (!inherits(norm_path, "try-error")) {
+    path <- norm_path
+  }
+  return(path)
+}
