@@ -4,10 +4,12 @@ test_that(".calc_population_count works", {
       package = "mapme.biodiversity"
     )
   )
-  worldpop <- list.files(system.file("res", "worldpop",
-    package = "mapme.biodiversity"
-  ), pattern = ".tif$", full.names = TRUE)
-  worldpop <- rast(worldpop)
+  .clear_resources()
+  outdir <- file.path(tempdir(), "mapme.data")
+  .copy_resource_dir(outdir)
+  mapme_options(outdir = outdir, verbose = FALSE)
+  get_resources(x, get_worldpop(years = 2010:2020))
+  worldpop <- prep_resources(x)[["worldpop"]]
 
   cpc <- calc_population_count()
   result <- cpc(x, worldpop)
